calculateRadius abstract method
Returns the blur radius of the touch ripple effect by a given instance and size.
Implementation
double calculateRadius(TouchRippleEffect effect, Size size);
Returns the blur radius of the touch ripple effect by a given instance and size.
double calculateRadius(TouchRippleEffect effect, Size size);