components/touch_ripple_gesture_recognizer library

Classes

HoldingGestureRecognizer
The gesture recognizer that tracks holding gestures, defined as when a pointer is pressed but not yet released. It resolves the gesture if the pointer is lifted.
TouchRippleDoubleTapGestureRecognizer
The gesture recognizer that tracks double-tap gestures.
TouchRippleDragGestureRecognizer
The gesture recognizer that tracks dragging gestures.
TouchRippleGestureRecognizer
The abstract class that defines the touch ripple gesture base behavior, which is a basic and essential behavior.
TouchRippleLongTapGestureRecognizer
The gesture recognizer that tracks long holding gestures.
TouchRippleTapGestureRecognizer
The gesture recognizer that tracks tap gestures.

Mixins

FocusableGestureRecognizerMixin
The mixin that adds focus gesture recognition to OneSequenceGestureRecognizer. Provides callbacks for when a focus gesture starts or ends.
HoldableGestureRecognizerMixin
The mixin provides functionality to continuously track the defined pointers to prevent the gesture from being rejected.

Typedefs

GestureRecognizerDisposeCallback = void Function(GestureRecognizer instance)
Signature for the callback function that is called when a GestureRecognizer disposed.