onDragVertical property
The callback function is called when the user dragging to top or bottom.
Implementation
final TouchRippleDragCallback? onDragVertical;
The callback function is called when the user dragging to top or bottom.
final TouchRippleDragCallback? onDragVertical;