detach method
Delegates the task of detaching and disposing of a touch ripple effect to ensure consistency with attach function.
Implementation
void detach(TouchRippleEffect effect) {
assert(
_states.contains(effect),
"Already not exists a given ripple effect.",
);
_states.remove(effect..removeListener(notifyListeners));
}