detachByKey method
Delegates the task of detaching and disposing of a touch ripple effect to ensure consistency with attachByKey function by a given key.
Implementation
void detachByKey(String key) {
assert(
_stateMap.containsKey(key),
"Already not exists a given ripple effect.",
);
_stateMap.remove(key)?..removeListener(notifyListeners);
}